OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Tasks" : "Задаци",
    "Personal" : "Лично",
    "{actor} created calendar {calendar}" : "{actor} направи календар {calendar}",
    "You created calendar {calendar}" : "Направили сте календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} обриса календар {calendar}",
    "You deleted calendar {calendar}" : "Обрисали сте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ажурира календар {calendar}",
    "You updated calendar {calendar}" : "Ажурирали сте календар {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} је обновио календар {calendar}",
    "You restored calendar {calendar}" : "Обновили сте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Поделили сте календар {calendar} као јавну везу",
    "You removed public link for calendar {calendar}" : "Уклонили сте јавну везу за календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} подели календар {calendar} са вама",
    "You shared calendar {calendar} with {user}" : "Поделили сте календар {calendar} са корисником {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} подели календар {calendar} са корисником {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} укину дељење календара {calendar} са вама",
    "You unshared calendar {calendar} from {user}" : "Укинули сте дељење календара {calendar} са корисником {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} укину дељење календара {calendar} кориснику {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} укину дељење календара {calendar} са њим",
    "You shared calendar {calendar} with group {group}" : "Поделили сте календар {calendar} са групом {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} подели календар {calendar} са групом {group}",
    "You unshared calendar {calendar} from group {group}" : "Укинули сте дељење календара {calendar} са групом {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} укину дељење календара {calendar} са групом {group}",
    "Untitled event" : "Неименовани догађај",
    "{actor} created event {event} in calendar {calendar}" : "{actor} је направио догађај {event} у календару {calendar}",
    "You created event {event} in calendar {calendar}" : "Креирали сте догађај {event} у календару {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} је обрисао догађај {event} из календара {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Обрисали сте догађај {event} из календара {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} је ажурирао догађај {event} у календару {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ажурирали сте догађај {event} у календару {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} је преместио догађај {event} из календара {sourceCalendar} у календар {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Преместили сте догађај {event} из календара {sourceCalendar} у календар {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} је обновио догађај {event} календара {calendar}",
    "You restored event {event} of calendar {calendar}" : "Обновили сте догађај {event} календара {calendar}",
    "Busy" : "Заузет/а",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} је креирао обавезу {todo} у листи {calendar}",
    "You created to-do {todo} in list {calendar}" : "Креирали сте обавезу {todo} у листи {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} је обрисао обавезу {todo} из листе {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "обрисали сте обавезу {todo} из листе {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} је ажурирао обавезу {todo} у листи {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Ажурирали сте обавезу {todo} у листи {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} је извршио обавезу {todo} у листи {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Извршили сте обавезу {todo} у листи {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} је поново отворио обавезу {todo} у листи {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Поново сте отворили обавезу {todo} у листи {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} је преместио обавезу {todo} из листе {sourceCalendar} у листу {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Преместили сте обавезу {todo} из листе {sourceCalendar} у листу {targetCalendar}",
    "Calendar, contacts and tasks" : "Календар, контакти и задаци",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> је измењен",
    "A calendar <strong>event</strong> was modified" : "<strong>Догађај</strong> из календара је измењен",
    "A calendar <strong>to-do</strong> was modified" : "Календар <strong>обавеза</strong> је измењен",
    "Contact birthdays" : "Рођендани контаката",
    "Death of %s" : " %s смрт",
    "Untitled calendar" : "Неименовани календар",
    "Calendar:" : "Календар:",
    "Date:" : "Датум:",
    "Where:" : "Место:",
    "Description:" : "Опис:",
    "_%n year_::_%n years_" : ["%n година","%n године","%n  година"],
    "_%n month_::_%n months_" : ["%n месец","%n месеца","%n месеци"],
    "_%n day_::_%n days_" : ["%n дан","%n дана","%n дана"],
    "_%n hour_::_%n hours_" : ["%n сат","%n сата","%n сати"],
    "_%n minute_::_%n minutes_" : ["%n минут","%n минута","%n минута"],
    "%s (in %s)" : "%s (у %s)",
    "%s (%s ago)" : "%s (пре %s)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Датум: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Место: %s",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "Cancelled: %1$s" : "Отказано: %1$s",
    "\"%1$s\" has been canceled" : "„%1$s” је отказано",
    "Re: %1$s" : "Одг: %1$s",
    "%1$s has accepted your invitation" : "%1$s је прихватио вашу позивницу",
    "%1$s has tentatively accepted your invitation" : "%1$s је условно прихватио вашу позивницу",
    "%1$s has declined your invitation" : "%1$s је одбио вашу позивницу",
    "%1$s has responded to your invitation" : "%1$s је одговорио на вашу позивницу",
    "Invitation updated: %1$s" : "Позивница је ажурирана: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s је ажурирао догађај „%2$s”",
    "Invitation: %1$s" : "Позивница: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s жели да вас позове на „%2$s",
    "Organizer:" : "Организатор:",
    "Attendees:" : "Присутни:",
    "Title:" : "Наслов:",
    "Time:" : "Време:",
    "Location:" : "Локација:",
    "Link:" : "Веза:",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "More options …" : "Још опција…",
    "More options at %s" : "Још опција на %s",
    "Contacts" : "Контакти",
    "{actor} created address book {addressbook}" : "{actor} је креирао адресар {addressbook}",
    "You created address book {addressbook}" : "Креирали сте адресар {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} је обрисао адресар {addressbook}",
    "You deleted address book {addressbook}" : "Обрисали сте адресар {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} је ажурирао адресар {addressbook}",
    "You updated address book {addressbook}" : "Ажурирали сте адресар {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} је са вама поделио адресар {addressbook}",
    "You shared address book {addressbook} with {user}" : "Поделили сте адресар {addressbook} са {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} је поделио адресар {addressbook} са {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} је уклонио дељење адресара {addressbook} са вама",
    "You unshared address book {addressbook} from {user}" : "Уклонили сте дељење адресара {addressbook} са {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} је уклонио дељење адресара {addressbook} са {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} више не дели адресар {addressbook} са собом",
    "You shared address book {addressbook} with group {group}" : "Поделили сте адресар {addressbook} са групом {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} је поделио адресар {addressbook} са групом {group}",
    "You unshared address book {addressbook} from group {group}" : "Уклонили сте дељење адресара {addressbook} са групом {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} је уклонио дељење адресара {addressbook} са групом {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} је креирао контакт {card} у адресару {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Креирали сте контакт {card} у адресару {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} је обрисао контакт {card} из адресара {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Обрисали сте контакт {card} из адресара {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} је ажурирао контакт {card} у адресару {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Ажурирали сте контакт {card} у адресару {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Измењен је <strong>контакт</strong> или <strong>адресар</strong>",
    "Accounts" : "Налози",
    "System address book which holds all accounts" : "Системски адресар у којем се налазе сви налози",
    "File is not updatable: %1$s" : "Фајл не може да се ажурира: %1$s",
    "Could not write to final file, canceled by hook" : "Не може да се упише у крајњи фајл, отказала је кука",
    "Could not write file contents" : "Не може да се упише садржај фајла",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Грешка приликом копирања фајла на циљну локацију (копирано: %1$s, очекивана величина фајла: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Очекивала се величина фајла %1$s, али је (од Nextcloud клијента) прочитано и уписано (у Nextcloud складиште) %2$s. Или може бити мрежни проблем на страни која шаље, или проблем код уписа у складиште на серверу.",
    "Could not rename part file to final file, canceled by hook" : "Делимични фајл не може да се преименује у коначни фајл, отказала је кука",
    "Could not rename part file to final file" : "Делимични фајл не може да се преименује у коначни фајл",
    "Failed to check file size: %1$s" : "Није успела провера величине фајла: %1$s",
    "Could not open file" : "Фајл не може да се отвори",
    "Encryption not ready: %1$s" : "Шифрирање није спремно: %1$s",
    "Failed to open file: %1$s" : "Фајл не може да се отвори: %1$s",
    "Failed to unlink: %1$s" : "Није успело уклањање линка: %1$s",
    "Invalid chunk name" : "Неисправни назив комада",
    "Could not rename part file assembled from chunks" : "Име делимичног фајла састављеног од комада не може да се промени",
    "Failed to write file contents: %1$s" : "Није успело уписивање садржаја фајла: %1$s",
    "File not found: %1$s" : "Фајл не може да се пронађе: %1$s",
    "System is in maintenance mode." : "Систем је у режиму одржавања.",
    "Upgrade needed" : "Потребна надградња",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s мора да буде подешен да користи HTTPS да бисте користи CalDAV и CardDAV са iOS/macOS-ом.",
    "Configures a CalDAV account" : "Подешава CalDAV налог",
    "Configures a CardDAV account" : "Подешава CardDAV налог",
    "Events" : "Догађаји",
    "Untitled task" : "Неименовани задатак",
    "Completed on %s" : "Завршено %s",
    "Due on %s by %s" : "Рок је %s од стране %s",
    "Due on %s" : "Рок је %s",
    "DAV system address book" : "DAV системски адресар",
    "No outstanding DAV system address book sync." : "Не постоји ниједна синхронизација DAV системског адресара која треба да се обави.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV синхронизација системског адресара се још увек није покренула јер ваша инстанца има више од 1000 корисника или јер је дошло до грешке. Молимо вас да га ручно покренете командом „occ dav:sync-system-addressbook”.",
    "Migrated calendar (%1$s)" : "Мигрирани календар (%1$s)",
    "Calendars including events, details and attendees" : "Календари који укључују догађаје, детаље и учеснике",
    "Contacts and groups" : "Контакти и групе",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV крајња тачка",
    "First day" : "Први дан",
    "Last day (inclusive)" : "Последњи дан (укључујући и њега)",
    "Short absence status" : "Кратак статус одсуства",
    "Long absence Message" : "Дугачак статус одсуства",
    "Save" : "Сачувај",
    "Disable absence" : "Искључи одсутност",
    "Absence saved" : "Одсутност је сачувана",
    "Failed to save your absence settings" : "Није успело чување ваших поставки одсутности",
    "Absence cleared" : "Одсутност је обрисана",
    "Failed to clear your absence settings" : "Није успело брисање ваших поставки одсутности",
    "Time zone:" : "Временска зона:",
    "to" : "за",
    "Delete slot" : "Обриши прорез",
    "No working hours set" : "Нису подешени радни сати",
    "Add slot" : "Додај термин",
    "Weekdays" : "Дани у недељи",
    "Monday" : "Понедељак",
    "Tuesday" : "Уторак",
    "Wednesday" : "Среда",
    "Thursday" : "Четвртак",
    "Friday" : "Петак",
    "Saturday" : "Субота",
    "Sunday" : "Недеља",
    "Pick a start time for {dayName}" : "Изаберите време почетка за {dayName}",
    "Pick a end time for {dayName}" : "Изаберите време завршетка за {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Аутоматски поставља статус кориниска на „Не узнемиравај” како би се ван доступности пригушила сва обавештења.",
    "Failed to load availability" : "Доступност није могла да се учита",
    "Saved availability" : "Доступност је сачувана",
    "Failed to save availability" : "Није успело снимање доступности ",
    "Availability" : "Доступност",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ако подесите своје радне сате, када буду заказивали састанак, други људи ће видети када сте ван канцеларије.",
    "Absence" : "Одсутност",
    "Configure your next absence period." : "Конфигуришите свој наредни период одсутности.",
    "Calendar server" : "Календар сервера",
    "Send invitations to attendees" : "Пошаљи позивницу учесницима",
    "Automatically generate a birthday calendar" : "Аутоматски изгенериши календар рођендана",
    "Birthday calendars will be generated by a background job." : "Календари рођендана ће бити генерисани као позадински послови.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Зато можда неће бити видљиви баш одмах по укључивању, али ће се појавити после неког времена.",
    "Send notifications for events" : "Шаљи обавештења о догађајима",
    "Notifications are sent via background jobs, so these must occur often enough." : "Обавештења се шаљу кроз послове у позадини, па би требало да су постављени да се често извршавају.",
    "Send reminder notifications to calendar sharees as well" : "Пошаљи подсетнике и корисницима којима је календар подељен",
    "Reminders are always sent to organizers and attendees." : "Подсетници се увек шаљу организаторима и учесницима.",
    "Enable notifications for events via push" : "Укључи обавештења за догађаје преко гурања догађаја",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Такође инсталирајте {calendarappstoreopen}Календар апликацију{linkclose}, или {calendardocopen}повежите Ваш рачунар & мобилни за синхронизацију ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Постарајте се да правилно подесите {emailopen}сервер е-поште{linkclose}.",
    "There was an error updating your attendance status." : "Десила се грешка приликом ажурирања статуса Вашег присуства.",
    "Please contact the organizer directly." : "Контактирајте директно организатора.",
    "Are you accepting the invitation?" : "Да ли прихватате позивницу?",
    "Tentative" : "Условна потврда",
    "Your attendance was updated successfully." : "Ваше присуство је успешно ажурирано.",
    "To-dos" : "Обавезе",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ако подесите своје радне сате, када буду заказивали састанак, остали корисници ће видети када сте ван канцеларије."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
